@@ -1,10 +1,7 @@
-from typing import Optional
-
 from .. import Provider as AddressProvider
 
 
 class Provider(AddressProvider):
-
     city_formats = ("{{city_name}}",)
 
     street_name_formats = ("{{street_name}}",)
@@ -1036,7 +1033,6 @@ class Provider(AddressProvider):
         "Lotyšsko",
         "Lucembursko",
         "Madagaskar",
-        "Makedonie",
         "Malajsie",
         "Malawi",
         "Maledivy",
@@ -1086,6 +1082,7 @@ class Provider(AddressProvider):
         "Saúdská Arábie",
         "Senegal",
         "Severní Korea",
+        "Severní Makedonie",
         "Seychely",
         "Sierra Leone",
         "Singapur",
@@ -1140,20 +1137,20 @@ class Provider(AddressProvider):
         "Švýcarsko",
     )
 
-    def street_suffix_short(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.street_suffixes_short, min_length, max_length)
+    def street_suffix_short(self) -> str:
+        return self.random_element(self.street_suffixes_short)
 
-    def street_suffix_long(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.street_suffixes_long, min_length, max_length)
+    def street_suffix_long(self) -> str:
+        return self.random_element(self.street_suffixes_long)
 
-    def city_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.cities, min_length, max_length)
+    def city_name(self) -> str:
+        return self.random_element(self.cities)
 
-    def street_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.streets, min_length, max_length)
+    def street_name(self) -> str:
+        return self.random_element(self.streets)
 
-    def administrative_unit(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.states, min_length, max_length)
+    def administrative_unit(self) -> str:
+        return self.random_element(self.states)
 
     state = administrative_unit
 
